==> huaweicloudsdkmetastudio-3.1.96-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_welcome_speech_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWelcomeSpeechRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'welcome_speech_id': 'str'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'welcome_speech_id': 'welcome_speech_id'
    }

    def __init__(self, x_app_user_id=None, welcome_speech_id=None):
        """ShowWelcomeSpeechRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 第三方用户ID。不允许输入中文。
        :type x_app_user_id: str
        :param welcome_speech_id: 欢迎词ID。
        :type welcome_speech_id: str
        """
        
        

        self._x_app_user_id = None
        self._welcome_speech_id = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.welcome_speech_id = welcome_speech_id

    @property
    def x_app_user_id(self):
        """Gets the x_app_user_id of this ShowWelcomeSpeechRequest.

        第三方用户ID。不允许输入中文。

        :return: The x_app_user_id of this ShowWelcomeSpeechRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        """Sets the x_app_user_id of this ShowWelcomeSpeechRequest.

        第三方用户ID。不允许输入中文。

        :param x_app_user_id: The x_app_user_id of this ShowWelcomeSpeechRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def welcome_speech_id(self):
        """Gets the welcome_speech_id of this ShowWelcomeSpeechRequest.

        欢迎词ID。

        :return: The welcome_speech_id of this ShowWelcomeSpeechRequest.
        :rtype: str
        """
        return self._welcome_speech_id

    @welcome_speech_id.setter
    def welcome_speech_id(self, welcome_speech_id):
        """Sets the welcome_speech_id of this ShowWelcomeSpeechRequest.

        欢迎词ID。

        :param welcome_speech_id: The welcome_speech_id of this ShowWelcomeSpeechRequest.
        :type welcome_speech_id: str
        """
        self._welcome_speech_id = welcome_speech_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWelcomeSpeechRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_welcome_speech_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWelcomeSpeechRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'welcome_speech_id': 'str'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'welcome_speech_id': 'welcome_speech_id'
    }

    def __init__(self, x_app_user_id=None, welcome_speech_id=None):
        r"""ShowWelcomeSpeechRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 第三方用户ID。不允许输入中文。
        :type x_app_user_id: str
        :param welcome_speech_id: 欢迎词ID。
        :type welcome_speech_id: str
        """
        
        

        self._x_app_user_id = None
        self._welcome_speech_id = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.welcome_speech_id = welcome_speech_id

    @property
    def x_app_user_id(self):
        r"""Gets the x_app_user_id of this ShowWelcomeSpeechRequest.

        第三方用户ID。不允许输入中文。

        :return: The x_app_user_id of this ShowWelcomeSpeechRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        r"""Sets the x_app_user_id of this ShowWelcomeSpeechRequest.

        第三方用户ID。不允许输入中文。

        :param x_app_user_id: The x_app_user_id of this ShowWelcomeSpeechRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def welcome_speech_id(self):
        r"""Gets the welcome_speech_id of this ShowWelcomeSpeechRequest.

        欢迎词ID。

        :return: The welcome_speech_id of this ShowWelcomeSpeechRequest.
        :rtype: str
        """
        return self._welcome_speech_id

    @welcome_speech_id.setter
    def welcome_speech_id(self, welcome_speech_id):
        r"""Sets the welcome_speech_id of this ShowWelcomeSpeechRequest.

        欢迎词ID。

        :param welcome_speech_id: The welcome_speech_id of this ShowWelcomeSpeechRequest.
        :type welcome_speech_id: str
        """
        self._welcome_speech_id = welcome_speech_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWelcomeSpeechRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
